@@ -410,6 +410,28 @@ sub build_via_tecmake {
 
   my %done;
 
+  if(-d "$srcdir/freetype/src") {
+    print STDERR "Gonna build 'freetype'\n";
+    chdir "$srcdir/freetype/src";
+    copy('../../iup/tecmake.mak', '../tecmake.mak') unless -f '../tecmakewin.mak'; #WORKAROUND
+    $done{"freetype"} = $self->run_custom($make, 'freetype', @{$mopts});
+    $success = 0 unless $done{"freetype"};
+    copy($_, "$prefixdir/include/") foreach (glob("../include/*.h"));
+    copy($_, "$prefixdir/lib/") foreach (glob("../lib/*/*"));
+    chdir $self->base_dir();
+  }
+
+  if(-d "$srcdir/ftgl/src") {
+    print STDERR "Gonna build 'ftgl'\n";
+    chdir "$srcdir/ftgl/src";
+    copy('../../iup/tecmake.mak', '../tecmake.mak') unless -f '../tecmakewin.mak'; #WORKAROUND
+    $done{"ftgl"} = $self->run_custom($make, 'ftgl', @{$mopts});
+    $success = 0 unless $done{"ftgl"};
+    copy($_, "$prefixdir/include/") foreach (glob("../include/*.h"));
+    copy($_, "$prefixdir/lib/") foreach (glob("../lib/*/*"));
+    chdir $self->base_dir();
+  }
+
   if(-d "$srcdir/im/src") {
     print STDERR "Gonna build 'im'\n";
     chdir "$srcdir/im/src";
